@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIResponse.h 2572 2007-10-13 00:10:23Z svn $
+ * $Id: CGIResponse.h 2588 2007-10-20 10:51:51Z svn $
  *****************************************************************************/
 
 #ifndef CGI_RESPONSE_H
@@ -73,10 +73,9 @@ public:
     {
         return get_env(r->pool, "CONTENT_TYPE");
     };
-    static apr_size_t get_content_size(Handle *r)
+    static apr_uint64_t get_content_size(Handle *r)
     {
-        return static_cast<apr_size_t>(apr_atoi64(get_env(r->pool,
-                                                         "CONTENT_LENGTH")));
+        return apr_atoi64(get_env(r->pool, "CONTENT_LENGTH"));
     };
     static const char *get_query(Handle *r)
     {
