@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RequestResponseImpl.h 2162 2006-12-03 14:36:10Z svn $
+ * $Id: RequestResponseImpl.h 2538 2007-07-16 15:21:45Z svn $
  *****************************************************************************/
 
 #ifndef REQUEST_RESPONSE_IMPL_H
@@ -31,16 +31,16 @@
 #include "Environment.h"
 
 // レスポンスのタイプ
-#if defined(RESPONSE_TYPE_APACHE)
+#if defined(UPLOADER_TYPE_APACHE)
 #define RESPONSE_TYPE ApacheResponse
 #include "ApacheRFC1867Parser.h"
 #include "ApacheRFC2822Parser.h"
 #include "ApacheTemplateExecutor.h"
 #include "ApacheUploadItemRss.h"
 #include "ApacheLogger.h"
-#elif defined(RESPONSE_TYPE_CGI)
+#elif defined(UPLOADER_TYPE_CGI)
 #define RESPONSE_TYPE CGIResponse
-#include "CGIRFC1867Parser.h"
+ #include "CGIRFC1867Parser.h"
 #include "CGIRFC2822Parser.h"
 #include "CGITemplateExecutor.h"
 #include "CGIUploadItemRss.h"
