@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2613 2007-10-28 02:47:22Z svn $
+ * $Id: uploader_handler.cpp 2623 2007-11-05 16:23:18Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2613 2007-10-28 02:47:22Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2623 2007-11-05 16:23:18Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -256,7 +256,8 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
             (TOTAL_FILE_SIZE_VAR_NAME,
              size_str(r->pool,
                       config->get_item_list()->get_total_file_size()));
-        var_creator.create(TOTAL_FILE_NUMBER_VAR_NAME, config->get_item_list()->size());
+        var_creator.create(TOTAL_FILE_NUMBER_VAR_NAME,
+                           config->get_item_list()->size());
         var_creator.create(PAGE_COUNT_VAR_NAME, page_count);
 
         var_creator.create(CURRENT_PAGE_VAR_NAME, page_no);
